* Galiani, S., & McEwan, P. J. (2013). The heterogeneous impact of conditional cash transfers. Journal of Public Economics, 103, 85-96.

** do file started Feb. 2011 by Patrick McEwan
** last revision prior to publication of Galiani and McEwan (2013)

version 12.1
clear all
set more off
cd "/Users/patrick/Desktop/Galiani and McEwan (2013)"

** Runs separate do file that calculate predicted poverty, based on a 1999 household survey;; creates poverty.dta
	do povertypredict.do

** Load census
	use "Data/census.dta",clear

*****************************
* File prep
*****************************

	global dependent = "attend work work_home"
	global individual = "age female borninmun lenca other moved"
	global household = "fatherliterate motherliterate fatherschool motherschool dirtfloor pipedwater electriclight householdrooms sewerseptic auto refrigerator computer television mitch hh_total hh_0_17"
	global squared = "fatherschool2 motherschool2 householdrooms2 hh_total2 hh_0_172"
	gen adultmale=1 if age>=21 & age<=65 & female==0
	gen adultfemale=1 if age>=21 & age<=65 & female==1

	* Merge predicted poverty, used in heterogeneity table as robustness check
		merge 1:1 g01-g12 p00 using poverty.dta
		drop _merge
		erase poverty.dta

	* Prepare treatment file
		preserve
		use "Data/treatment.dta",clear
		gen interaction=moderate*severe
		gen oldshaz=shaz // municipal height-for-age available for 70 experimental municipalities
		replace shaz=int(shaz*10000)
		gen shaz1=shaz
		gen shaz2=shaz
		egen new=max(shaz)
		replace shaz1=new if shaz==.
		foreach g in 717 1511 1805 {
			replace shaz1=-23862 if municipio==`g'
			replace shaz2=-23678 if municipio==`g'
		}
		intreg shaz1 shaz2 severe moderate interaction [aweight=N]
		predict shazhat if e(sample)==1
		replace shazhat=round(shazhat,1)
		drop new shaz1 shaz2 shaz rankmuni moderate severe N interaction

		gen demand=0 // Dummy variable indicating whether individual resides in "demand-side" CCT municipality (the published paper refers to this as "CCT")
		replace demand=1 if treatment==1 | treatment==2
		save "treatment_working.dta",replace
		restore
		
	** Merge municipal-level treatment file with treatment, block, and height-for-age data used in regression-discontinuity robustness check
		merge m:1 municipio using treatment_working.dta
		erase treatment_working.dta
		drop _merge

	gen sample=1 if treatment~=. // residing in 70 experimental municipalities
	tab treatment,gen(T) // G1, G2, G3, G4 indicators
	
*************************
* Descriptive statistics
*************************

* Table 1, Descriptives
	cap log close
	log using "Output/descriptives", replace
	summarize $dependent $individual $household poorhat if eligible==1
	summarize $dependent $individual $household poorhat if eligible==1 & sample==1
	summarize $dependent $individual $household poorhat if eligible==1 & sample==1 & treatment==1
	summarize $dependent $individual $household poorhat if eligible==1 & sample==1 & treatment==2
	summarize $dependent $individual $household poorhat if eligible==1 & sample==1 & treatment==3
	summarize $dependent $individual $household poorhat if eligible==1 & sample==1 & treatment==4

	foreach v in $dependent $individual $household poorhat {
		reg `v' T1 T2 T3 i.block if eligible==1, cluster(municipio)
		testparm T1 T2 T3
	}

* Table 3
	by block,s: summarize $dependent poorhat if eligible==1 & (treatment==3 | treatment==4)
	by block,s: summarize $dependent if eligible==1 & (treatment==3 | treatment==4) & female==0
	by block,s: summarize $dependent if eligible==1 & (treatment==3 | treatment==4) & female==1
	by block,s: summarize work work_home if (treatment==3 | treatment==4) & adultmale==1
	by block,s: summarize work work_home if (treatment==3 | treatment==4) & adultfemale==1

**************
** Figure 3 **
**************

histogram oldshaz if oldshaz>-3.1 & eligible==1, nodraw ///
	color(gs10) ///
	start(-3.1) w(.05) ///
	xline(-2.7885 -2.6308 -2.4793 -2.363 -2.304, lp(dot)) ///
	xlab(-3.1(.1)-2.3) ///
	plotregion(style(none)) ///
	name(histogram,replace) ///
	xti("HAZ") 

	foreach v in attend {
	cap drop shaz1 smooth*
	lpoly `v' oldshaz if (treatment==1 | treatment==2) & eligible==1 & oldshaz>-3.1, ///
		xlab(-3.1(.1)-2.3) ///
		xline(-2.7885 -2.6308 -2.4793 -2.363 -2.304, lp(dot)) ///
		ylab(.5(.1).8) ///
		yti("Enrolled") ///
		xti("HAZ") ///
		ti("") note("") caption("") ///
		noscatter bwidth(.3) degree(1) kernel(rectangle) generate(shaz1 smooth1) nodraw ///
		addplot(lpoly `v' oldshaz if (treatment==3 | treatment==4) & eligible==1 & oldshaz>-3.1, bwidth(.3) degree(1) kernel(rectangle)) ///
		name(`v',replace) ///
		lineop(lp(dash)) ///
		legend(off)	///
		plotregion(style(none))
		drop shaz1 smooth
		}

	foreach v in work {
	cap drop shaz1 smooth*
	lpoly `v' oldshaz if (treatment==1 | treatment==2) & eligible==1 & oldshaz>-3.1, ///
		xlab(-3.1(.1)-2.3) ///
		ylab(.02(.03).2) ///
		xline(-2.7885 -2.6308 -2.4793 -2.363 -2.304, lp(dot)) ///
		yti("Works oustide home") ///
		xti("HAZ") ///
		ti("") note("") caption("") ///
		noscatter bwidth(.3) degree(1) kernel(rectangle) generate(shaz1 smooth1) nodraw ///
		addplot(lpoly `v' oldshaz if (treatment==3 | treatment==4) & eligible==1 & oldshaz>-3.1, bwidth(.3) degree(1) kernel(rectangle)) ///
		name(`v',replace) ///
		lineop(lp(dash)) ///
		legend(off)	///
		plotregion(style(none))
		drop shaz1 smooth
		}

	foreach v in work_home {
	cap drop shaz1 smooth*
	lpoly `v' oldshaz if (treatment==1 | treatment==2) & eligible==1 & oldshaz>-3.1, ///
		xlab(-3.1(.1)-2.3) ///
		ylab(.02(.03).2) ///
		xline(-2.7885 -2.6308 -2.4793 -2.363 -2.304, lp(dot)) ///
		yti("Works only in home") ///
		xti("HAZ") ///
		ti("") note("") caption("") ///
		noscatter bwidth(.3) degree(1) kernel(rectangle) generate(shaz1 smooth1) nodraw ///
		addplot(lpoly `v' oldshaz if (treatment==3 | treatment==4) & eligible==1 & oldshaz>-3.1, bwidth(.3) degree(1) kernel(rectangle)) ///
		name(`v',replace) ///
		lineop(lp(dash)) ///
		legend(off)	///
		plotregion(style(none))
		drop shaz1 smooth
		}
graph combine attend work work_home histogram

**********************************************
* Create variables/macros for regressions
**********************************************

*  Treatment indicators
	foreach n in 1 2 3 4 5 {
	gen demand`n'=demand
	replace demand`n'=0 if block~=`n'
	}

	gen demand_low=demand
	replace demand_low=0 if block~=1 & block~=2
	gen demand_high=demand
	replace demand_high=0 if block~=3 & block~=4 & block~=5

* Squared terms
	gen motherschool2=motherschool^2
	gen fatherschool2=fatherschool^2
	gen householdrooms2=householdrooms^2
	gen hh_0_172= hh_0_17^2
	gen hh_total2= hh_total^2 

** Replace missing values for categorical/factor variables
	foreach v in $individual $household $squared {
		replace `v'=999 if `v'==.
	}

** Replace missing values for continuous variables, and create dummies
	foreach v in fatherschool fatherschool2 motherschool motherschool2 householdrooms householdrooms2 hh_total hh_total2 hh_0_17 hh_0_172 {
		gen `v'_miss=1 if `v'==999
		replace `v'_miss=0 if `v'~=999
		}

gen el_e=eligible_hh
	recode el_e 0=0 1=1 2=2 3/max=3
gen el_h=eligible_hh_health
	recode el_h 0=0 1=1 2/max=2

global r_individual = "i.age female borninmun lenca other i.moved"
global r_household = "i.fatherliterate i.motherliterate fatherschool fatherschool2 motherschool motherschool2 fatherschool_miss motherschool_miss i.dirtfloor i.pipedwater i.electriclight householdrooms householdrooms2 householdrooms_miss i.sewerseptic i.auto"
global r_household2 = "i.refrigerator i.computer i.television i.mitch hh_total hh_total2 hh_0_17 hh_0_172 hh_total_miss hh_0_17_miss i.el_e i.el_h"

**********************************************
* Regressions
**********************************************

* Table 2; Eligible children

cap erase "Output/regressions_eligible.txt"

foreach v in attend work work_home {
	reg `v' T1 T2 T3 i.block if eligible==1, cluster(municipio)
	test T1=T2
		local p1 = r(p)
	test T2=T3
		outreg2 T1 T2 T3 using "Output/regressions_eligible", nocons adjr2 10pct dec(3) adds("p-value",`p1', "p-value 2",`r(p)') adec(3)

	reg `v' T1 T2 T3 i.block $r_individual $r_household $r_household2 if eligible==1, cluster(municipio)
	test T1=T2
		local p1 = r(p)
	test T2=T3
		outreg2 T1 T2 T3 using "Output/regressions_eligible", nocons adjr2 10pct dec(3) adds("p-value",`p1', "p-value 2",`r(p)') adec(3)

	reg `v' demand i.block if eligible==1, cluster(municipio)
		outreg2 demand using "Output/regressions_eligible", nocons adjr2 10pct dec(3)
	
	reg `v' demand i.block $r_individual $r_household $r_household2 if eligible==1, cluster(municipio)
		outreg2 demand using "Output/regressions_eligible", nocons adjr2 10pct dec(3)

	reg `v' demand1 demand2 demand3 demand4 demand5 i.block  if eligible==1, cluster(municipio)
		test demand1=demand2=demand3=demand4=demand5
		outreg2 demand1 demand2 demand3 demand4 demand5  using "Output/regressions_eligible", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)

	reg `v' demand1 demand2 demand3 demand4 demand5 i.block $r_individual $r_household $r_household2 if eligible==1, cluster(municipio)
		test demand1=demand2=demand3=demand4=demand5
		outreg2 demand1 demand2 demand3 demand4 demand5  using "Output/regressions_eligible", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)

	reg `v' demand_low demand_high i.block  if eligible==1, cluster(municipio)
		test demand_low=demand_high
		outreg2 demand_low demand_high using "Output/regressions_eligible", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)

	reg `v' demand_low demand_high i.block $r_individual $r_household $r_household2 if eligible==1, cluster(municipio)
		test demand_low=demand_high
		outreg2 demand_low demand_high using "Output/regressions_eligible", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	}

* Table 5; Not eligible

cap erase "Output/regressions_not.txt"

foreach v in attend work work_home {
* No eligible children in HH
	reg `v' demand i.block $r_individual $r_household $r_household2 if eligible~=1 & age>=6 & age<=12 & eligible_hh==0 & eligible_hh_health==0, cluster(municipio)
			outreg2 demand using "Output/regressions_not", nocons adjr2 10pct dec(3)

	reg `v' demand1 demand2 demand3 demand4 demand5 i.block $r_individual $r_household $r_household2 if eligible~=1 & age>=6 & age<=12  & eligible_hh==0 & eligible_hh_health==0, cluster(municipio)
		test demand1=demand2=demand3=demand4=demand5
		outreg2 demand1 demand2 demand3 demand4 demand5  using "Output/regressions_not", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)

* At least one child eligible for education transfer in HH
	reg `v' demand i.block $r_individual $r_household $r_household2 if eligible~=1 & age>=6 & age<=12 & (eligible_hh~=0 ), cluster(municipio)
			outreg2 demand using "Output/regressions_not", nocons adjr2 10pct dec(3)

	reg `v' demand1 demand2 demand3 demand4 demand5 i.block $r_individual $r_household $r_household2 if eligible~=1 & age>=6 & age<=12  & (eligible_hh~=0 ), cluster(municipio)
		test demand1=demand2=demand3=demand4=demand5
		outreg2 demand1 demand2 demand3 demand4 demand5  using "Output/regressions_not", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)

* At least one child eligible for education or health transfer in HH
	reg `v' demand i.block $r_individual $r_household $r_household2 if eligible~=1 & age>=6 & age<=12 & (eligible_hh~=0 | eligible_hh_health~=0), cluster(municipio)
			outreg2 demand using "Output/regressions_not", nocons adjr2 10pct dec(3)

	reg `v' demand1 demand2 demand3 demand4 demand5 i.block $r_individual $r_household $r_household2 if eligible~=1 & age>=6 & age<=12  & (eligible_hh~=0 | eligible_hh_health~=0), cluster(municipio)
		test demand1=demand2=demand3=demand4=demand5
		outreg2 demand1 demand2 demand3 demand4 demand5  using "Output/regressions_not", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	}

* Table 6; adults

cap erase "Output/regressions_adultwork.txt"

foreach v in adultmale adultfemale {

preserve
keep if `v'==1

	* No eligible children in HH
foreach v in work work_home {
	reg `v' demand i.block $r_individual $r_household $r_household2 if eligible_hh==0 & eligible_hh_health==0, cluster(municipio)
		outreg2 demand using "Output/regressions_adultwork", nocons adjr2 10pct dec(3)

	reg `v' demand1 demand2 demand3 demand4 demand5 i.block $r_individual $r_household $r_household2 if eligible_hh==0 & eligible_hh_health==0, cluster(municipio)
		test demand1=demand2=demand3=demand4=demand5
		outreg2 demand1 demand2 demand3 demand4 demand5  using "Output/regressions_adultwork", nocons adjr2 10pct dec(3) adds("p value",`r(p)') adec(3)
	}

	* At least one child eligible for education transfer in HH

foreach v in work work_home {
	reg `v' demand i.block $r_individual $r_household $r_household2 if eligible_hh~=0, cluster(municipio)
		outreg2 demand using "Output/regressions_adultwork", nocons adjr2 10pct dec(3)

	reg `v' demand1 demand2 demand3 demand4 demand5 i.block $r_individual $r_household $r_household2 if eligible_hh~=0, cluster(municipio)
		test demand1=demand2=demand3=demand4=demand5
		outreg2 demand1 demand2 demand3 demand4 demand5  using "Output/regressions_adultwork", nocons adjr2 10pct dec(3) adds("p value",`r(p)') adec(3)
	}

	* At least one child eligible for education or health transfer in HH

foreach v in work work_home {
	reg `v' demand i.block $r_individual $r_household $r_household2 if (eligible_hh~=0 | eligible_hh_health~=0), cluster(municipio)
		outreg2 demand using "Output/regressions_adultwork", nocons adjr2 10pct dec(3)

	reg `v' demand1 demand2 demand3 demand4 demand5 i.block $r_individual $r_household $r_household2 if (eligible_hh~=0 | eligible_hh_health~=0), cluster(municipio)
		test demand1=demand2=demand3=demand4=demand5
		outreg2 demand1 demand2 demand3 demand4 demand5  using "Output/regressions_adultwork", nocons adjr2 10pct dec(3) adds("p value",`r(p)') adec(3)
	}

	restore
	}

* Table 4; Heterogeneous effects amnong eligibles

cap erase "Output/heterogeneous.txt"

gen demandpoor=demand*poorhat
foreach v in attend work work_home {
	reg `v' demand demandpoor i.block $r_individual $r_household $r_household2 poorhat if eligible==1 & (block==1 | block==2), cluster(municipio)
		outreg2 demand demandpoor using "Output/heterogeneous", nocons adjr2 10pct dec(3)  
	reg `v' demand demandpoor i.block $r_individual $r_household $r_household2 poorhat if eligible==1 & (block==3 | block==4 | block==5), cluster(municipio)
		outreg2 demand demandpoor using "Output/heterogeneous", nocons adjr2 10pct dec(3)  
	}

foreach n in 6 7 8 9 10 11 12 {
	gen demand`n'=demand
	replace demand`n'=0 if age~=`n'
	}

foreach v in attend work work_home {
	reg `v' demand6-demand12 i.block $r_individual $r_household $r_household2 if eligible==1, cluster(municipio)
		test demand6=demand7=demand8=demand9=demand10=demand11=demand12
		outreg2 demand6 demand7 demand8 demand9 demand10 demand11 demand12 using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	reg `v' demand6-demand12 i.block $r_individual $r_household $r_household2 if eligible==1 & (block==1 | block==2), cluster(municipio)
		test demand6=demand7=demand8=demand9=demand10=demand11=demand12
		outreg2 demand6 demand7 demand8 demand9 demand10 demand11 demand12 using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	reg `v' demand6-demand12 i.block $r_individual $r_household $r_household2 if eligible==1 & (block==3 | block==4 | block==5), cluster(municipio)
		test demand6=demand7=demand8=demand9=demand10=demand11=demand12
		outreg2 demand6 demand7 demand8 demand9 demand10 demand11 demand12 using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	}

gen demand_female=demand
	replace demand_female=0 if female==0
gen demand_male=demand
	replace demand_male=0 if female==1

foreach v in attend work work_home {
	reg `v' demand_female demand_male i.block $r_individual $r_household $r_household2 if eligible==1, cluster(municipio)
		test demand_female=demand_male
		outreg2 demand_female demand_male using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	reg `v' demand_female demand_male i.block $r_individual $r_household $r_household2 if eligible==1 & (block==1 | block==2), cluster(municipio)
		test demand_female=demand_male
		outreg2 demand_female demand_male using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	reg `v' demand_female demand_male i.block $r_individual $r_household $r_household2 if eligible==1 & (block==3 | block==4 | block==5), cluster(municipio)
		test demand_female=demand_male
		outreg2 demand_female demand_male using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	}

gen demand_0to3=demand
	replace demand_0to3=0 if eligible_hh>=4
gen demand_4ormore=demand
	replace demand_4ormore=0 if eligible_hh>=1 & eligible_hh<=3

foreach v in attend work work_home {
	reg `v' demand_0to3 demand_4ormore i.block $r_individual $r_household $r_household2 if eligible==1, cluster(municipio)
		test demand_0to3=demand_4ormore
		outreg2 demand_0to3 demand_4ormore using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	reg `v' demand_0to3 demand_4ormore i.block $r_individual $r_household $r_household2 if eligible==1 & (block==1 | block==2), cluster(municipio)
		test demand_0to3=demand_4ormore
		outreg2 demand_0to3 demand_4ormore using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	reg `v' demand_0to3 demand_4ormore i.block $r_individual $r_household $r_household2 if eligible==1 & (block==3 | block==4 | block==5), cluster(municipio)
		test demand_0to3=demand_4ormore
		outreg2 demand_0to3 demand_4ormore using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	}

gen demand_health=demand
	replace demand_health=0 if eligible_hh_health==0
gen demand_nohealth=demand
	replace demand_nohealth=0 if eligible_hh_health>=1

foreach v in attend work work_home {
	reg `v' demand_health demand_nohealth i.block $r_individual $r_household $r_household2 if eligible==1, cluster(municipio)
		test demand_health=demand_nohealth
		outreg2 demand_health demand_nohealth using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	reg `v' demand_health demand_nohealth i.block $r_individual $r_household $r_household2 if eligible==1 & (block==1 | block==2), cluster(municipio)
		test demand_health=demand_nohealth
		outreg2 demand_health demand_nohealth using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	reg `v' demand_health demand_nohealth i.block $r_individual $r_household $r_household2 if eligible==1 & (block==3 | block==4 | block==5), cluster(municipio)
		test demand_health=demand_nohealth
		outreg2 demand_health demand_nohealth using "Output/heterogeneous", nocons adjr2 10pct dec(3) adds("p-value",`r(p)') adec(3)
	}

gen demand_noschool=demand if motherschool_miss==0
	replace demand_noschool=0 if motherschool_miss==0 & motherschool>0
gen demand_school=demand if motherschool_miss==0
	replace demand_school=0 if motherschool_miss==0 & motherschool==0
foreach v in attend work work_home {
	reg `v' demand_school demand_noschool i.block $r_individual $r_household $r_household2 if eligible==1, cluster(municipio)
		outreg2 demand_school demand_noschool using "Output/heterogeneous", nocons adjr2 10pct dec(3)  
	reg `v' demand_school demand_noschool i.block $r_individual $r_household $r_household2 if eligible==1 & (block==1 | block==2), cluster(municipio)
		outreg2 demand_school demand_noschool using "Output/heterogeneous", nocons adjr2 10pct dec(3)  
	reg `v' demand_school demand_noschool i.block $r_individual $r_household $r_household2 if eligible==1 & (block==3 | block==4 | block==5), cluster(municipio)
		outreg2 demand_school demand_noschool using "Output/heterogeneous", nocons adjr2 10pct dec(3)  
	}

**************************
* Figure 4 and Table 7 
**************************

* Generate discontinuity variables
	gen     e=1 if shazhat<=-23040
	replace e=0 if shazhat>-23040
	gen i=(shazhat+23040)/10000
	gen i2=i^2
	gen i3=i^3

	gen ii=((shazhat+23040)/10000)*e
	gen ii2=ii^2
	gen ii3=ii^3


keep if shazhat~=. // predicted municipal height-for-age
	
* Figure 4

foreach v in demand motherschool attend work {
	cap drop shaz1
	cap drop smooth1
	cap drop smooth2
	cap drop smooth3
	cap drop smooth4

	lpoly `v' i if eligible==1 & e==0 & `v'~=999 & i>=-.6 & i<=1.1, noscatter bwidth(.3) degree(1) kernel(rectangle) generate(shaz1 smooth1) nodraw
		preserve
		keep shaz1 smooth1
		drop if shaz1==.
		save temp, replace		
		restore
		drop shaz1 smooth*
	lpoly `v' i if eligible==1 & e==1 & `v'~=999 & i>=-.6 & i<=1.1, noscatter bwidth(.3) degree(1) kernel(rectangle) generate(shaz1 smooth2) nodraw
		preserve
		keep shaz1 smooth2
		drop if shaz1==.
		append using temp

	if "`v'"=="demand" local yt = "CCT"
	if "`v'"=="attend" local yt = "Enrolled"
	if "`v'"=="work" local yt = "Works outside home"
	if "`v'"=="work_home" local yt = "Works only in home"
	if "`v'"=="motherschool" local yt = "Mother's schooling"
	if "`v'"=="dirtfloor" local yt = "Dirt floor"
	if "`v'"=="electriclight" local yt = "Electricity"

	if "`v'"=="demand" local yl = "0(.2)1"
	if "`v'"=="attend" local yl = ".5(.1).9"
	if "`v'"=="work" local yl = "0(.04).2"
	if "`v'"=="work_home" local yl = "0(.04).2"
	if "`v'"=="motherschool" local yl = "0(1)7"
	if "`v'"=="dirtfloor" local yl = "0(.2).1"

	scatter smooth1 smooth2 shaz1 , ///
	xline(0, lp(dot)) ///
	ylab(`yl') ///
	msym(i i )				///
	mlc(none none )			///
	c(l l ) ///
	lp(solid solid ) ///
	lw( medium medium) ///
	clc( black black) ///
	yti("`yt'") ///
	xti("HAZ[hat] + 2.304") ///
	legend(off) ///
	plotregion(style(none)) ///
	sort ///
	name(`v'`p',replace)

		restore
		erase temp.dta
	}

graph combine demand attend work motherschool
	
	* Test for balance in baseline variables near discontinuity
	cap erase "Output/discontinuity_baseline.txt"
	foreach v in  motherschool {
	foreach bw in .5 {
		reg `v' i i2 e   if `v'~=999 & eligible==1 & i>=-`bw' & i<=`bw', cluster(municipio)
				outreg2 e using "Output/discontinuity_baseline", 10pct dec(3) adjr2 nocons adds("bandwidth",`bw')
		reg `v' i i2 i3 e   if `v'~=999 & eligible==1 & i>=-`bw' & i<=`bw', cluster(municipio)
				outreg2 e using "Output/discontinuity_baseline", 10pct dec(3) adjr2 nocons adds("bandwidth",`bw')
		reg `v' i ii e   if `v'~=999 & eligible==1 & i>=-`bw' & i<=`bw', cluster(municipio)
				outreg2 e using "Output/discontinuity_baseline", 10pct dec(3) adjr2 nocons adds("bandwidth",`bw')
	}
	}

	cap erase "Output/discontinuity.txt"
	foreach v in  demand attend work work_home {
	foreach bw in .5 {
		reg `v' i ii e $r_individual $r_household $r_household2  if `v'~=999 & eligible==1 & i>=-`bw' & i<=`bw', cluster(municipio)
				outreg2 e using "Output/discontinuity", 10pct dec(3) adjr2 nocons adds("bandwidth",`bw')
		reg `v' i i2 e $r_individual $r_household $r_household2  if `v'~=999 & eligible==1 & i>=-`bw' & i<=`bw', cluster(municipio)
				outreg2 e using "Output/discontinuity", 10pct dec(3) adjr2 nocons adds("bandwidth",`bw')
		reg `v' i i2 i3 e $r_individual $r_household $r_household2  if `v'~=999 & eligible==1 & i>=-`bw' & i<=`bw', cluster(municipio)
				outreg2 e using "Output/discontinuity", 10pct dec(3) adjr2 nocons adds("bandwidth",`bw')
	}
	}
	
exit
