version 12.1
clear all
set more off

* 1999 extreme poverty line: 538.5 L./person/month
* File calculates poverty, estimates logit, and uses estimates to predict poverty in sample of eligible children in 70 municipios

use "Data/ecftse99.dta" // 1999 household survey

*******************
** Variable prep 
*******************

* Calculate individual poverty using household income per capita from original data file
	gen poor=0 if yperchog~=.
	replace poor=1 if yperchog<538.5
	
* Calculate variables that are also available in census
	* Note that BORNINMUN, LENCA, OTHER, AUTO, COMPUTER, TELEVISION, and MITCH are not in household survey

	egen hh=group(depto munic domi rep seg vivi hogar)
	rename edad age
	rename sexo female
	recode female 1=0 2=1

	gen literate=p3
	recode literate 0=. 1=1 6=0
	gen temp=literate if female==0 & (rela_j==1 | rela_j==2)
	egen fatherliterate=max(temp),by(hh)
	drop temp
	gen temp=literate if female==1 & (rela_j==1 | rela_j==2)
	egen motherliterate=max(temp),by(hh)
	drop temp literate
	gen school=0 if p5_1==1 | p5_1==2 | p5_1==3
	replace school=p5_2 if p5_1==4
	replace school=p5_2+6 if p5_1==5
	replace school=p5_2+6 if p5_1==6
	replace school=p5_2+12 if p5_1==7
	replace school=p5_2+12 if p5_1==8
	gen temp=school if female==0 & (rela_j==1 | rela_j==2)
	egen fatherschool=max(temp),by(hh)
	drop temp
	gen temp=school if female==1 & (rela_j==1 | rela_j==2)
	egen motherschool=max(temp),by(hh)
	drop temp

	gen dirtfloor=pv3
	recode dirtfloor 1/4=0 5=1
	gen pipedwater=pv4a
	recode pipedwater 1/2=1 3/5=0
	gen electriclight=pv6
	recode electriclight 1/3=1 4=0
	gen householdrooms=pv8b
	recode householdrooms 99=.
	gen sewerseptic=0
	replace sewerseptic=1 if pv5a==1 & (pv5b==4 | pv5b==5)

	gen temp=1
	gen temp2=1 if age>=0 & age<=17
	egen hh_total=total(temp),by(hh)
	egen hh_0_17=total(temp2),by(hh)
	drop temp temp2

* Missing values
	
	foreach v in fatherliterate motherliterate  {
		replace `v'=999 if `v'==.
	}

	foreach v in fatherschool motherschool {
		gen `v'2=`v'^2
		gen `v'_m=0
		replace `v'_m=1 if `v'==.
		replace `v'=0 if `v'==.
		replace `v'2=0 if `v'2==.
	}

gen householdrooms2=householdrooms^2
gen hh_total2=hh_total^2
gen hh_0_172=hh_0_17^2

*******************
** Sample and logit
*******************

sum poor [fweight=factor]

* Restrict sample to children eligible to receive transfer
    keep if age>=6 & age<=12
    drop if school>4
    drop if school==4 & p4==6

* Povery logit
	tab fatherliterate,gen(FL) // no need for missing indicator b/c it is perfectly collinear with father's schooling
	tab motherliterate,gen(ML) // same as above
	tab age,gen(A)

logit poor A2 A3 A4 A5 A6 A7 female FL2 ML2 fatherschool fatherschool2 fatherschool_m motherschool motherschool2 motherschool_m dirtfloor pipedwater electriclight householdrooms householdrooms2 sewerseptic hh_total hh_total2 hh_0_17  hh_0_172, cluster(hh)
sum poor [fweight=factor]

*******************
** Predict in census
*******************

use "Data/census.dta",clear
keep if eligible==1 // Children eligible to receive transfer, 6-12 years-old and incomplete 4th grade

tab age,gen(A)
rename fatherliterate FL2
rename motherliterate ML2

foreach v in fatherschool motherschool {
	gen `v'2=`v'^2
	gen `v'_m=1 if `v'==.
	replace `v'_m=0 if `v'~=.
	replace `v'=0 if `v'_m==1
	replace `v'2=0 if `v'_m==1
	}

replace FL2=0 if fatherschool_m==1
replace ML2=0 if motherschool_m==1

foreach v in hh_total hh_0_17 householdrooms {
	gen `v'2=`v'^2
	}

predict poorhat
keep if poorhat~=.
keep g01-g12 p00 poorhat
save poverty,replace
